@@ -1,8 +1,8 @@
 (function () {
     "use strict";
 
-    /* malevic@0.18.6 - Jul 15, 2020 */
-    function m(tagOrComponent, props, ...children) {
+    /* malevic@0.19.1 - Jan 8, 2022 */
+    function m$1(tagOrComponent, props, ...children) {
         props = props || {};
         if (typeof tagOrComponent === "string") {
             const tag = tagOrComponent;
@@ -15,7 +15,7 @@
         throw new Error("Unsupported spec type");
     }
 
-    /* malevic@0.18.6 - Jul 15, 2020 */
+    /* malevic@0.19.1 - Jan 8, 2022 */
     function createPluginsStore() {
         const plugins = [];
         return {
@@ -395,6 +395,18 @@
         }
     }
 
+    function m(tagOrComponent, props, ...children) {
+        props = props || {};
+        if (typeof tagOrComponent === "string") {
+            const tag = tagOrComponent;
+            return {type: tag, props, children};
+        }
+        if (typeof tagOrComponent === "function") {
+            const component = tagOrComponent;
+            return {type: component, props, children};
+        }
+        throw new Error("Unsupported spec type");
+    }
     function isSpec(x) {
         return isObject(x) && x.type != null && x.nodeType == null;
     }
@@ -1134,7 +1146,33 @@
         return nodes[0];
     }
 
-    /* malevic@0.18.6 - Jul 15, 2020 */
+    function normalize(attrsOrChild, ...otherChildren) {
+        const attrs =
+            isObject(attrsOrChild) && !isSpec(attrsOrChild)
+                ? attrsOrChild
+                : null;
+        const children =
+            attrs == null
+                ? [attrsOrChild].concat(otherChildren)
+                : otherChildren;
+        return {attrs, children};
+    }
+    function createTagFunction(tag) {
+        return (attrsOrChild, ...otherChildren) => {
+            const {attrs, children} = normalize(attrsOrChild, otherChildren);
+            return m(tag, attrs, children);
+        };
+    }
+    new Proxy(
+        {},
+        {
+            get: (_, tag) => {
+                return createTagFunction(tag);
+            }
+        }
+    );
+
+    /* malevic@0.19.1 - Jan 8, 2022 */
 
     let currentUseStateFn = null;
     function useState(initialState) {
@@ -1186,13 +1224,12 @@
 
     const MessageType = {
         UI_GET_DATA: "ui-get-data",
-        UI_GET_ACTIVE_TAB_INFO: "ui-get-active-tab-info",
         UI_SUBSCRIBE_TO_CHANGES: "ui-subscribe-to-changes",
         UI_UNSUBSCRIBE_FROM_CHANGES: "ui-unsubscribe-from-changes",
         UI_CHANGE_SETTINGS: "ui-change-settings",
         UI_SET_THEME: "ui-set-theme",
         UI_SET_SHORTCUT: "ui-set-shortcut",
-        UI_TOGGLE_URL: "ui-toggle-url",
+        UI_TOGGLE_ACTIVE_TAB: "ui-toggle-active-tab",
         UI_MARK_NEWS_AS_READ: "ui-mark-news-as-read",
         UI_LOAD_CONFIG: "ui-load-config",
         UI_APPLY_DEV_DYNAMIC_THEME_FIXES: "ui-apply-dev-dynamic-theme-fixes",
@@ -1221,7 +1258,9 @@
         CS_FRAME_FREEZE: "cs-frame-freeze",
         CS_FRAME_RESUME: "cs-frame-resume",
         CS_EXPORT_CSS_RESPONSE: "cs-export-css-response",
-        CS_FETCH: "cs-fetch"
+        CS_FETCH: "cs-fetch",
+        CS_DARK_THEME_DETECTED: "cs-dark-theme-detected",
+        CS_DARK_THEME_NOT_DETECTED: "cs-dark-theme-not-detected"
     };
 
     const userAgent =
@@ -1272,7 +1311,7 @@
         }
         const el = document.createElement("div");
         el.setAttribute("style", "color-scheme: dark");
-        return el.style.colorScheme === "dark";
+        return el.style && el.style.colorScheme === "dark";
     })();
 
     function classes(...args) {
@@ -1368,10 +1407,10 @@
     function Button(props, ...children) {
         const cls = mergeClass("button", props.class);
         const attrs = omitAttrs(["class"], props);
-        return m(
+        return m$1(
             "button",
             {class: cls, ...attrs},
-            m("span", {class: "button__wrapper"}, ...children)
+            m$1("span", {class: "button__wrapper"}, ...children)
         );
     }
 
@@ -1771,7 +1810,7 @@
     function TextBox(props) {
         const cls = mergeClass("textbox", props.class);
         const attrs = omitAttrs(["class", "type"], props);
-        return m("input", {
+        return m$1("input", {
             class: cls,
             type: "text",
             spellcheck: "false",
@@ -1946,10 +1985,10 @@
             "left": `${activeHSB.s * 100}%`,
             "top": `${(1 - activeHSB.b) * 100}%`
         };
-        return m(
+        return m$1(
             "span",
             {class: "hsb-picker"},
-            m(
+            m$1(
                 "span",
                 {
                     class: "hsb-picker__sb-container",
@@ -1967,16 +2006,16 @@
                         store.sbTouchStartHandler = onSBPointerDown;
                     }
                 },
-                m("canvas", {
+                m$1("canvas", {
                     class: "hsb-picker__sb-canvas",
                     onrender: onSBCanvasRender
                 }),
-                m("span", {
+                m$1("span", {
                     class: "hsb-picker__sb-cursor",
                     style: sbCursorStyle
                 })
             ),
-            m(
+            m$1(
                 "span",
                 {
                     class: "hsb-picker__hue-container",
@@ -1994,11 +2033,11 @@
                         store.hueTouchStartHandler = onHuePointerDown;
                     }
                 },
-                m("canvas", {
+                m$1("canvas", {
                     class: "hsb-picker__hue-canvas",
                     onrender: onHueCanvasRender
                 }),
-                m("span", {
+                m$1("span", {
                     class: "hsb-picker__hue-cursor",
                     style: hueCursorStyle
                 })
@@ -2065,7 +2104,7 @@
                 blur();
             }
         }
-        const textBox = m(TextBox, {
+        const textBox = m$1(TextBox, {
             class: "color-picker__input",
             onrender: (el) => {
                 store.textBoxNode = el;
@@ -2082,7 +2121,7 @@
             },
             onfocus: focus
         });
-        const previewElement = m("span", {
+        const previewElement = m$1("span", {
             class: "color-picker__preview",
             onclick: toggleFocus,
             onrender: (el) => {
@@ -2093,7 +2132,7 @@
             }
         });
         const resetButton = props.canReset
-            ? m("span", {
+            ? m$1("span", {
                   role: "button",
                   class: "color-picker__reset",
                   onclick: () => {
@@ -2102,7 +2141,7 @@
                   }
               })
             : null;
-        const textBoxLine = m(
+        const textBoxLine = m$1(
             "span",
             {class: "color-picker__textbox-line"},
             textBox,
@@ -2110,17 +2149,17 @@
             resetButton
         );
         const hsbLine = isColorValid
-            ? m(
+            ? m$1(
                   "span",
                   {class: "color-picker__hsb-line"},
-                  m(HSBPicker, {
+                  m$1(HSBPicker, {
                       color: props.color,
                       onChange: onColorChange,
                       onColorPreview: onColorPreview
                   })
               )
             : null;
-        return m(
+        return m$1(
             "span",
             {
                 class: [
@@ -2129,7 +2168,7 @@
                     props.class
                 ]
             },
-            m("span", {class: "color-picker__wrapper"}, textBoxLine, hsbLine)
+            m$1("span", {class: "color-picker__wrapper"}, textBoxLine, hsbLine)
         );
     }
     Object.assign(ColorPicker, {focus: focusColorPicker});
@@ -2177,17 +2216,17 @@
     var Overlay$1 = Object.assign(Overlay, {Portal});
 
     function MessageBox(props) {
-        return m(
+        return m$1(
             Overlay$1.Portal,
             {key: props.portalKey, onOuterClick: props.onCancel},
-            m(
+            m$1(
                 "div",
                 {class: "message-box"},
-                m("label", {class: "message-box__caption"}, props.caption),
-                m(
+                m$1("label", {class: "message-box__caption"}, props.caption),
+                m$1(
                     "div",
                     {class: "message-box__buttons"},
-                    m(
+                    m$1(
                         Button,
                         {
                             class: "message-box__button message-box__button-ok",
@@ -2195,7 +2234,7 @@
                         },
                         "OK"
                     ),
-                    m(
+                    m$1(
                         Button,
                         {
                             class: "message-box__button message-box__button-cancel",
@@ -2316,12 +2355,12 @@
 
     function getCurrentThemePreset(props) {
         const custom = props.data.settings.customThemes.find(({url}) =>
-            isURLInList(props.tab.url, url)
+            isURLInList(props.data.activeTab.url, url)
         );
         const preset = custom
             ? null
             : props.data.settings.presets.find(({urls}) =>
-                  isURLInList(props.tab.url, urls)
+                  isURLInList(props.data.activeTab.url, urls)
               );
         let theme = custom
             ? custom.theme
@@ -2362,14 +2401,14 @@
         };
     }
 
-    function Body({data, tab, actions}) {
+    function Body({data, actions}) {
         const context = getComponentContext();
         const {state, setState} = useState({errorText: null});
         let textNode;
         const previewButtonText = data.settings.previewNewDesign
             ? "Switch to old design"
             : "Preview new design";
-        const {theme} = getCurrentThemePreset({data, tab, actions});
+        const {theme} = getCurrentThemePreset({data, actions});
         const wrapper =
             theme.engine === ThemeEngines.staticTheme
                 ? {
@@ -2437,7 +2476,7 @@
         }
         const dialog =
             context && context.store.isDialogVisible
-                ? m(MessageBox, {
+                ? m$1(MessageBox, {
                       caption:
                           "Are you sure you want to remove current changes? You cannot restore them later.",
                       onOK: reset,
@@ -2454,21 +2493,21 @@
                 previewNewDesign: !data.settings.previewNewDesign
             });
         }
-        return m(
+        return m$1(
             "body",
             null,
-            m(
+            m$1(
                 "header",
                 null,
-                m("img", {
+                m$1("img", {
                     id: "logo",
                     src: "../assets/images/darkreader-type.svg",
                     alt: "Dark Reader"
                 }),
-                m("h1", {id: "title"}, "Developer Tools")
+                m$1("h1", {id: "title"}, "Developer Tools")
             ),
-            m("h3", {id: "sub-title"}, wrapper.header),
-            m("textarea", {
+            m$1("h3", {id: "sub-title"}, wrapper.header),
+            m$1("textarea", {
                 id: "editor",
                 onrender: onTextRender,
                 spellcheck: "false",
@@ -2476,26 +2515,26 @@
                 autocomplete: "off",
                 autocapitalize: "off"
             }),
-            m("label", {id: "error-text"}, state.errorText),
-            m(
+            m$1("label", {id: "error-text"}, state.errorText),
+            m$1(
                 "div",
                 {id: "buttons"},
-                m(Button, {onclick: showDialog}, "Reset changes", dialog),
-                m(Button, {onclick: apply}, "Apply"),
-                m(
+                m$1(Button, {onclick: showDialog}, "Reset changes", dialog),
+                m$1(Button, {onclick: apply}, "Apply"),
+                m$1(
                     Button,
                     {class: "preview-design-button", onclick: toggleDesign},
                     previewButtonText
                 )
             ),
-            m(
+            m$1(
                 "p",
                 {id: "description"},
                 "Read about this tool ",
-                m(
+                m$1(
                     "strong",
                     null,
-                    m(
+                    m$1(
                         "a",
                         {
                             href: DEVTOOLS_DOCS_URL,
@@ -2506,11 +2545,11 @@
                     )
                 ),
                 ". If a ",
-                m("strong", null, "popular"),
+                m$1("strong", null, "popular"),
                 " website looks incorrect e-mail to ",
-                m("strong", null, "DarkReaderApp@gmail.com")
+                m$1("strong", null, "DarkReaderApp@gmail.com")
             ),
-            m(Overlay$1, null)
+            m$1(Overlay$1, null)
         );
     }
     var Body$1 = withState(Body);
@@ -2560,14 +2599,6 @@
             }
             return await this.sendRequest(MessageType.UI_GET_DATA);
         }
-        async getActiveTabInfo() {
-            if (isFirefox) {
-                return await this.firefoxSendRequestWithResponse(
-                    MessageType.UI_GET_ACTIVE_TAB_INFO
-                );
-            }
-            return await this.sendRequest(MessageType.UI_GET_ACTIVE_TAB_INFO);
-        }
         subscribeToChanges(callback) {
             this.changeSubscribers.add(callback);
             if (this.changeSubscribers.size === 1) {
@@ -2595,10 +2626,10 @@
                 data: theme
             });
         }
-        toggleURL(url) {
+        toggleActiveTab() {
             chrome.runtime.sendMessage({
-                type: MessageType.UI_TOGGLE_URL,
-                data: url
+                type: MessageType.UI_TOGGLE_ACTIVE_TAB,
+                data: {}
             });
         }
         markNewsAsRead(ids) {
@@ -2675,21 +2706,15 @@
         }
     }
 
-    function renderBody(data, tab, actions) {
-        sync(
-            document.body,
-            m(Body$1, {data: data, tab: tab, actions: actions})
-        );
+    function renderBody(data, actions) {
+        sync(document.body, m$1(Body$1, {data: data, actions: actions}));
     }
     async function start() {
         const connector = new Connector();
         window.addEventListener("unload", () => connector.disconnect());
         const data = await connector.getData();
-        const tabInfo = await connector.getActiveTabInfo();
-        renderBody(data, tabInfo, connector);
-        connector.subscribeToChanges((data) =>
-            renderBody(data, tabInfo, connector)
-        );
+        renderBody(data, connector);
+        connector.subscribeToChanges((data) => renderBody(data, connector));
     }
     start();
 })();
