@@ -1,8 +1,8 @@
 (function () {
     "use strict";
 
-    /* malevic@0.18.6 - Jul 15, 2020 */
-    function m(tagOrComponent, props, ...children) {
+    /* malevic@0.19.1 - Jan 8, 2022 */
+    function m$1(tagOrComponent, props, ...children) {
         props = props || {};
         if (typeof tagOrComponent === "string") {
             const tag = tagOrComponent;
@@ -15,7 +15,7 @@
         throw new Error("Unsupported spec type");
     }
 
-    /* malevic@0.18.6 - Jul 15, 2020 */
+    /* malevic@0.19.1 - Jan 8, 2022 */
     function createPluginsStore() {
         const plugins = [];
         return {
@@ -395,6 +395,18 @@
         }
     }
 
+    function m(tagOrComponent, props, ...children) {
+        props = props || {};
+        if (typeof tagOrComponent === "string") {
+            const tag = tagOrComponent;
+            return {type: tag, props, children};
+        }
+        if (typeof tagOrComponent === "function") {
+            const component = tagOrComponent;
+            return {type: component, props, children};
+        }
+        throw new Error("Unsupported spec type");
+    }
     function isSpec(x) {
         return isObject(x) && x.type != null && x.nodeType == null;
     }
@@ -1134,15 +1146,40 @@
         return nodes[0];
     }
 
+    function normalize(attrsOrChild, ...otherChildren) {
+        const attrs =
+            isObject(attrsOrChild) && !isSpec(attrsOrChild)
+                ? attrsOrChild
+                : null;
+        const children =
+            attrs == null
+                ? [attrsOrChild].concat(otherChildren)
+                : otherChildren;
+        return {attrs, children};
+    }
+    function createTagFunction(tag) {
+        return (attrsOrChild, ...otherChildren) => {
+            const {attrs, children} = normalize(attrsOrChild, otherChildren);
+            return m(tag, attrs, children);
+        };
+    }
+    new Proxy(
+        {},
+        {
+            get: (_, tag) => {
+                return createTagFunction(tag);
+            }
+        }
+    );
+
     const MessageType = {
         UI_GET_DATA: "ui-get-data",
-        UI_GET_ACTIVE_TAB_INFO: "ui-get-active-tab-info",
         UI_SUBSCRIBE_TO_CHANGES: "ui-subscribe-to-changes",
         UI_UNSUBSCRIBE_FROM_CHANGES: "ui-unsubscribe-from-changes",
         UI_CHANGE_SETTINGS: "ui-change-settings",
         UI_SET_THEME: "ui-set-theme",
         UI_SET_SHORTCUT: "ui-set-shortcut",
-        UI_TOGGLE_URL: "ui-toggle-url",
+        UI_TOGGLE_ACTIVE_TAB: "ui-toggle-active-tab",
         UI_MARK_NEWS_AS_READ: "ui-mark-news-as-read",
         UI_LOAD_CONFIG: "ui-load-config",
         UI_APPLY_DEV_DYNAMIC_THEME_FIXES: "ui-apply-dev-dynamic-theme-fixes",
@@ -1171,7 +1208,9 @@
         CS_FRAME_FREEZE: "cs-frame-freeze",
         CS_FRAME_RESUME: "cs-frame-resume",
         CS_EXPORT_CSS_RESPONSE: "cs-export-css-response",
-        CS_FETCH: "cs-fetch"
+        CS_FETCH: "cs-fetch",
+        CS_DARK_THEME_DETECTED: "cs-dark-theme-detected",
+        CS_DARK_THEME_NOT_DETECTED: "cs-dark-theme-not-detected"
     };
 
     const userAgent =
@@ -1222,7 +1261,7 @@
         }
         const el = document.createElement("div");
         el.setAttribute("style", "color-scheme: dark");
-        return el.style.colorScheme === "dark";
+        return el.style && el.style.colorScheme === "dark";
     })();
 
     function classes(...args) {
@@ -1318,10 +1357,10 @@
     function Button(props, ...children) {
         const cls = mergeClass("button", props.class);
         const attrs = omitAttrs(["class"], props);
-        return m(
+        return m$1(
             "button",
             {class: cls, ...attrs},
-            m("span", {class: "button__wrapper"}, ...children)
+            m$1("span", {class: "button__wrapper"}, ...children)
         );
     }
 
@@ -1721,7 +1760,7 @@
     function TextBox(props) {
         const cls = mergeClass("textbox", props.class);
         const attrs = omitAttrs(["class", "type"], props);
-        return m("input", {
+        return m$1("input", {
             class: cls,
             type: "text",
             spellcheck: "false",
@@ -1896,10 +1935,10 @@
             "left": `${activeHSB.s * 100}%`,
             "top": `${(1 - activeHSB.b) * 100}%`
         };
-        return m(
+        return m$1(
             "span",
             {class: "hsb-picker"},
-            m(
+            m$1(
                 "span",
                 {
                     class: "hsb-picker__sb-container",
@@ -1917,16 +1956,16 @@
                         store.sbTouchStartHandler = onSBPointerDown;
                     }
                 },
-                m("canvas", {
+                m$1("canvas", {
                     class: "hsb-picker__sb-canvas",
                     onrender: onSBCanvasRender
                 }),
-                m("span", {
+                m$1("span", {
                     class: "hsb-picker__sb-cursor",
                     style: sbCursorStyle
                 })
             ),
-            m(
+            m$1(
                 "span",
                 {
                     class: "hsb-picker__hue-container",
@@ -1944,11 +1983,11 @@
                         store.hueTouchStartHandler = onHuePointerDown;
                     }
                 },
-                m("canvas", {
+                m$1("canvas", {
                     class: "hsb-picker__hue-canvas",
                     onrender: onHueCanvasRender
                 }),
-                m("span", {
+                m$1("span", {
                     class: "hsb-picker__hue-cursor",
                     style: hueCursorStyle
                 })
@@ -2015,7 +2054,7 @@
                 blur();
             }
         }
-        const textBox = m(TextBox, {
+        const textBox = m$1(TextBox, {
             class: "color-picker__input",
             onrender: (el) => {
                 store.textBoxNode = el;
@@ -2032,7 +2071,7 @@
             },
             onfocus: focus
         });
-        const previewElement = m("span", {
+        const previewElement = m$1("span", {
             class: "color-picker__preview",
             onclick: toggleFocus,
             onrender: (el) => {
@@ -2043,7 +2082,7 @@
             }
         });
         const resetButton = props.canReset
-            ? m("span", {
+            ? m$1("span", {
                   role: "button",
                   class: "color-picker__reset",
                   onclick: () => {
@@ -2052,7 +2091,7 @@
                   }
               })
             : null;
-        const textBoxLine = m(
+        const textBoxLine = m$1(
             "span",
             {class: "color-picker__textbox-line"},
             textBox,
@@ -2060,17 +2099,17 @@
             resetButton
         );
         const hsbLine = isColorValid
-            ? m(
+            ? m$1(
                   "span",
                   {class: "color-picker__hsb-line"},
-                  m(HSBPicker, {
+                  m$1(HSBPicker, {
                       color: props.color,
                       onChange: onColorChange,
                       onColorPreview: onColorPreview
                   })
               )
             : null;
-        return m(
+        return m$1(
             "span",
             {
                 class: [
@@ -2079,7 +2118,7 @@
                     props.class
                 ]
             },
-            m("span", {class: "color-picker__wrapper"}, textBoxLine, hsbLine)
+            m$1("span", {class: "color-picker__wrapper"}, textBoxLine, hsbLine)
         );
     }
     Object.assign(ColorPicker, {focus: focusColorPicker});
@@ -2127,17 +2166,17 @@
     var Overlay$1 = Object.assign(Overlay, {Portal});
 
     function MessageBox(props) {
-        return m(
+        return m$1(
             Overlay$1.Portal,
             {key: props.portalKey, onOuterClick: props.onCancel},
-            m(
+            m$1(
                 "div",
                 {class: "message-box"},
-                m("label", {class: "message-box__caption"}, props.caption),
-                m(
+                m$1("label", {class: "message-box__caption"}, props.caption),
+                m$1(
                     "div",
                     {class: "message-box__buttons"},
-                    m(
+                    m$1(
                         Button,
                         {
                             class: "message-box__button message-box__button-ok",
@@ -2145,7 +2184,7 @@
                         },
                         "OK"
                     ),
-                    m(
+                    m$1(
                         Button,
                         {
                             class: "message-box__button message-box__button-cancel",
@@ -2263,11 +2302,11 @@
         return new RegExp(result, "i");
     }
 
-    function Body({data, tab, actions}) {
+    function Body({data, actions}) {
         const context = getComponentContext();
-        const host = getURLHostOrProtocol(tab.url);
+        const host = getURLHostOrProtocol(data.activeTab.url);
         const custom = data.settings.customThemes.find(({url}) =>
-            isURLInList(tab.url, url)
+            isURLInList(data.activeTab.url, url)
         );
         let textNode;
         const placeholderText = [
@@ -2306,7 +2345,7 @@
         }
         const dialog =
             context && context.store.isDialogVisible
-                ? m(MessageBox, {
+                ? m$1(MessageBox, {
                       caption:
                           "Are you sure you want to remove current changes? You cannot restore them later.",
                       onOK: reset,
@@ -2321,21 +2360,21 @@
             const css = textNode.value;
             applyStyleSheet(css);
         }
-        return m(
+        return m$1(
             "body",
             null,
-            m(
+            m$1(
                 "header",
                 null,
-                m("img", {
+                m$1("img", {
                     id: "logo",
                     src: "../assets/images/darkreader-type.svg",
                     alt: "Dark Reader"
                 }),
-                m("h1", {id: "title"}, "CSS Editor")
+                m$1("h1", {id: "title"}, "CSS Editor")
             ),
-            m("h3", {id: "sub-title"}, custom ? host : "All websites"),
-            m("textarea", {
+            m$1("h3", {id: "sub-title"}, custom ? host : "All websites"),
+            m$1("textarea", {
                 id: "editor",
                 native: true,
                 placeholder: placeholderText,
@@ -2345,13 +2384,13 @@
                 autocomplete: "off",
                 autocapitalize: "off"
             }),
-            m(
+            m$1(
                 "div",
                 {id: "buttons"},
-                m(Button, {onclick: showDialog}, "Reset changes", dialog),
-                m(Button, {onclick: apply}, "Apply")
+                m$1(Button, {onclick: showDialog}, "Reset changes", dialog),
+                m$1(Button, {onclick: apply}, "Apply")
             ),
-            m(Overlay$1, null)
+            m$1(Overlay$1, null)
         );
     }
 
@@ -2400,14 +2439,6 @@
             }
             return await this.sendRequest(MessageType.UI_GET_DATA);
         }
-        async getActiveTabInfo() {
-            if (isFirefox) {
-                return await this.firefoxSendRequestWithResponse(
-                    MessageType.UI_GET_ACTIVE_TAB_INFO
-                );
-            }
-            return await this.sendRequest(MessageType.UI_GET_ACTIVE_TAB_INFO);
-        }
         subscribeToChanges(callback) {
             this.changeSubscribers.add(callback);
             if (this.changeSubscribers.size === 1) {
@@ -2435,10 +2466,10 @@
                 data: theme
             });
         }
-        toggleURL(url) {
+        toggleActiveTab() {
             chrome.runtime.sendMessage({
-                type: MessageType.UI_TOGGLE_URL,
-                data: url
+                type: MessageType.UI_TOGGLE_ACTIVE_TAB,
+                data: {}
             });
         }
         markNewsAsRead(ids) {
@@ -2515,18 +2546,15 @@
         }
     }
 
-    function renderBody(data, tab, actions) {
-        sync(document.body, m(Body, {data: data, tab: tab, actions: actions}));
+    function renderBody(data, actions) {
+        sync(document.body, m$1(Body, {data: data, actions: actions}));
     }
     async function start() {
         const connector = new Connector();
         window.addEventListener("unload", () => connector.disconnect());
         const data = await connector.getData();
-        const tab = await connector.getActiveTabInfo();
-        renderBody(data, tab, connector);
-        connector.subscribeToChanges((data) =>
-            renderBody(data, tab, connector)
-        );
+        renderBody(data, connector);
+        connector.subscribeToChanges((data) => renderBody(data, connector));
     }
     start();
 })();
